@@ -1,21 +1,7 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2014-2021 Greenbone Networks GmbH
+# SPDX-FileCopyrightText: 2014-2023 Greenbone AG
 #
 # SPDX-License-Identifier: AGPL-3.0-or-later
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
-
 
 # pylint: disable=too-many-lines
 
@@ -29,7 +15,7 @@ from typing import Optional, Dict, List, Tuple, Iterator, Any
 from datetime import datetime
 
 from pathlib import Path
-from os import geteuid, environ
+from os import geteuid
 
 import psutil
 
@@ -50,22 +36,9 @@ from ospd_openvas.nvticache import NVTICache
 from ospd_openvas.db import MainDB, BaseDB
 from ospd_openvas.lock import LockFile
 from ospd_openvas.preferencehandler import PreferenceHandler
-from ospd_openvas.openvas import Openvas
+from ospd_openvas.openvas import NASLCli, Openvas
 from ospd_openvas.vthelper import VtHelper
 from ospd_openvas.messaging.mqtt import MQTTClient, MQTTDaemon, MQTTSubscriber
-from ospd_openvas.feed import Feed
-
-SENTRY_DSN_OSPD_OPENVAS = environ.get("SENTRY_DSN_OSPD_OPENVAS")
-if SENTRY_DSN_OSPD_OPENVAS:
-    # pylint: disable=import-error
-    import sentry_sdk
-
-    sentry_sdk.init(  # pylint: disable=abstract-class-instantiated
-        SENTRY_DSN_OSPD_OPENVAS,
-        traces_sample_rate=1.0,
-        server_name=environ.get('SENTRY_SERVER_NAME'),
-        environment=environ.get('SENTRY_ENVIRONMENT'),
-    )
 
 logger = logging.getLogger(__name__)
 
@@ -472,6 +445,7 @@ class OSPDopenvas(OSPDaemon):
         lock_file_dir='/var/lib/openvas',
         mqtt_broker_address="localhost",
         mqtt_broker_port=1883,
+        feed_updater="openvas",
         disable_notus_hashsum_verification=False,
         **kwargs,
     ):
@@ -488,6 +462,7 @@ class OSPDopenvas(OSPDaemon):
                 disable_notus_hashsum_verification,
             )
 
+        self.feed_updater = feed_updater
         self.nvti = NVTICache(self.main_db)
 
         super().__init__(
@@ -519,7 +494,6 @@ class OSPDopenvas(OSPDaemon):
         self._mqtt_broker_port = mqtt_broker_port
 
     def init(self, server: BaseServer) -> None:
-
         notus_handler = NotusResultHandler(self.report_results)
 
         if self._mqtt_broker_address:
@@ -610,7 +584,6 @@ class OSPDopenvas(OSPDaemon):
         feed_info = {}
         with feed_info_file.open(encoding='utf-8') as fcontent:
             for line in fcontent:
-
                 try:
                     key, value = line.split('=', 1)
                 except ValueError:
@@ -655,10 +628,10 @@ class OSPDopenvas(OSPDaemon):
                 else:
                     feed_status["lockfile_in_use"] = '1'
 
-        feed = Feed()
-        _exit_error, _error_msg = feed.perform_feed_sync_self_test_success()
-        feed_status["self_test_exit_error"] = str(_exit_error)
-        feed_status["self_test_error_msg"] = _error_msg
+        # The feed self test is not performed any more, but the following
+        # entries are kept for backward compatibility.
+        feed_status["self_test_exit_error"] = "0"
+        feed_status["self_test_error_msg"] = None
 
         return feed_status
 
@@ -672,8 +645,13 @@ class OSPDopenvas(OSPDaemon):
         # reload notus cache
         if self.notus:
             self.notus.reload_cache()
+        loaded = False
+        if self.feed_updater == "nasl-cli":
+            loaded = NASLCli.load_vts_into_redis()
+        else:
+            loaded = Openvas.load_vts_into_redis()
 
-        if Openvas.load_vts_into_redis():
+        if loaded:
             new = self.nvti.get_feed_version()
             if new != old:
                 logger.info(
@@ -1000,7 +978,6 @@ class OSPDopenvas(OSPDaemon):
 
     @staticmethod
     def is_openvas_process_alive(openvas_process: psutil.Popen) -> bool:
-
         try:
             if openvas_process.status() == psutil.STATUS_ZOMBIE:
                 logger.debug("Process is a Zombie, waiting for it to clean up")
@@ -1191,7 +1168,6 @@ class OSPDopenvas(OSPDaemon):
 
         got_results = False
         while True:
-
             openvas_process_is_alive = self.is_openvas_process_alive(
                 openvas_process
             )
