@@ -1,20 +1,7 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2014-2021 Greenbone Networks GmbH
+# SPDX-FileCopyrightText: 2014-2023 Greenbone AG
 #
 # SPDX-License-Identifier: AGPL-3.0-or-later
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 from typing import Optional, Dict, Any
 
@@ -28,6 +15,22 @@ logger = logging.getLogger(__name__)
 _BOOL_DICT = {'no': 0, 'yes': 1}
 
 
+class NASLCli:
+    """Class for calling nasl-cli executable"""
+
+    @staticmethod
+    def load_vts_into_redis() -> bool:
+        """Loads all VTs into the redis database"""
+        try:
+            subprocess.check_call(
+                ['nasl-cli', 'feed', 'update'], stdout=subprocess.DEVNULL
+            )
+            return True
+        except (subprocess.SubprocessError, OSError) as err:
+            logger.error('nasl-cli failed to load VTs. %s', err)
+            return False
+
+
 class Openvas:
     """Class for calling the openvas executable"""
 
